Test cases
==========

Here are various examples to test pathological plots.

.. toctree::
   :maxdepth: 2

..   TestMatrix.rst
.. TestLayout.rst
.. TestHistogram.rst
.. TestMultiHistogram.rst
.. TestMultilinePlot.rst
.. TestLegend.rst
.. TestErrors.rst
.. TestUser.rst
   TestExceptions.rst
.. TestStatus.rst
.. TestParameter.rst
.. TestConfig.rst 
.. TestTable.rst
.. TestLargeMatrix.rst
.. TestRRendering.rst
   TestSandbox.rst
